@@ -47,7 +47,7 @@ test_that("matrix-vector products work", {
   M <- matrix(rnorm(n*n), n)
   x <- rnorm(n)
   expect_equal(as.numeric(M %*% x), M %m*v% x)
-  M <- as(M, "dgCMatrix")
+  M <- as(M, "CsparseMatrix")
   expect_equal(as.vector(M %*% x), M %m*v% x)
   M <- crossprod(M)
   expect_equal(as.vector(M %*% x), M %m*v% x)
@@ -74,7 +74,7 @@ test_that("matrix-vector crossproducts work", {
   M <- matrix(rnorm(n*n), n)
   x <- rnorm(n)
   expect_equal(as.numeric(crossprod(M, x)), crossprod_mv(M, x))
-  M <- as(M, "dgCMatrix")
+  M <- as(M, "CsparseMatrix")
   expect_equal(as.vector(crossprod(M, x)), crossprod_mv(M, x))
   M <- crossprod(M)
   expect_equal(as.vector(crossprod(M, x)), crossprod_mv(M, x))
@@ -107,13 +107,13 @@ test_that("tab to dgC conversion works", {
   m1 <- matrix(c(1,0,1,0,1,0,0,0,0), 3, 3)
   M1 <- as(m1, "tabMatrix")
   expect_false(M1@num)
-  expect_equal(Ctab2dgC(M1), as(m1, "dgCMatrix"))
+  expect_equal(Ctab2dgC(M1), as(as(m1, "CsparseMatrix"), "generalMatrix"))
   m1 <- matrix(c(2,0,0), 3, 1)
   M1 <- as(m1, "tabMatrix")
   expect_true(M1@num)
-  expect_equal(Ctab2dgC(M1), as(m1, "dgCMatrix"))
+  expect_equal(Ctab2dgC(M1), as(as(m1, "CsparseMatrix"), "generalMatrix"))
   M2 <- aggrMatrix(sample(1:7, 11, replace=TRUE))
-  expect_equal(Ctab2dgC(M2), as(as(M2, "CsparseMatrix"), "dgCMatrix"))
+  expect_equal(Ctab2dgC(M2), as(as(M2, "CsparseMatrix"), "generalMatrix"))
   M2 <- aggrMatrix(sample(1:7, 11, replace=TRUE), w=runif(11))
   expect_equivalent(as(Ctab2dgC(M2), "matrix"), Ctab2mat(M2))
   expect_error(as(matrix(c(1,1,1,0), 2, 2), "tabMatrix"))
@@ -178,8 +178,8 @@ test_that("crossprod_sym2 works", {
   expect_equal(crossprod_sym2(M1), crossprod(M1))
   M2 <- diag(runif(n)) %*% M1
   expect_equal(crossprod_sym2(M1, M2), crossprod(M1, M2))
-  M1 <- as(M1, "dgCMatrix")
-  M2 <- as(M2, "dgCMatrix")
+  M1 <- as(as(M1, "CsparseMatrix"), "generalMatrix")
+  M2 <- as(as(M2, "CsparseMatrix"), "generalMatrix")
   expect_equal(crossprod_sym2(M1), crossprod(M1))
   expect_equal(crossprod_sym2(M1, M2), as(crossprod(M1, M2), "symmetricMatrix"))
 })
